@@ -15,9 +15,6 @@ from ispyb.strictordereddict import StrictOrderedDict
 class MXProcessing(ispyb.interface.processing.IF):
   '''MXProcessing provides methods to store MX processing data.'''
 
-  def __init__(self):
-    pass
-
   _program_params = StrictOrderedDict([('id',None), ('cmd_line',None), ('programs',None),
     ('status',None), ('message',None), ('starttime',None), ('updatetime',None), ('environment',None), ('processing_job_id',None),
     ('recordtime',None)])
@@ -126,6 +123,25 @@ class MXProcessing(ispyb.interface.processing.IF):
     '''Store new or update existing program params.'''
     return self.get_connection().call_sp_write(procname='upsert_processing_program', args=values) # doesn't work with dict cursors
 
+  def upsert_program_ex(self, program_id=None, job_id=None, name=None,
+      command=None, environment=None, message=None, status=None,
+      time_defined=None, time_start=None, time_update=None):
+    '''Store new or update existing processing program information.
+
+       :param status: An integer describing the processing status. 1 means
+                      success, 0 means failure. If left at None then the
+                      status is left undefined or unchanged. The underlying
+                      stored procedure does not allow any more changes to the
+                      record once the status is set.
+       :return: The program_id.
+    '''
+    return self.get_connection().call_sp_write(
+        procname='upsert_processing_program',
+        args=[ program_id, command, name, status, message,
+               time_start, time_update, environment, job_id,
+               time_defined ],
+    )
+
   def upsert_program_attachment(self, values):
     '''Store new or update existing program attachment params.'''
     return self.get_connection().call_sp_write(procname='upsert_processing_program_attachment', args=values)
